@@ -26,7 +26,7 @@
  * @copyright 2009-2014 SQLI <www.sqli.com>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.3
+ * @version   Release: 1.5.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
@@ -208,10 +208,12 @@ class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
                     // Uppercase.
                     if ($lastWasUpper === false) {
                         $friendlyName .= ' ';
-                        $next = $name[($i + 1)];
-                        if (strtolower($next) === $next) {
-                            // Next char is lowercase so it is a word boundary.
-                            $name[$i] = strtolower($name[$i]);
+                        if ($i < ($length - 1)) {
+                            $next = $name[($i + 1)];
+                            if (strtolower($next) === $next) {
+                                // Next char is lowercase so it is a word boundary.
+                                $name[$i] = strtolower($name[$i]);
+                            }
                         }
                     }
 
