@@ -29,7 +29,7 @@ if (class_exists('PHP_CodeSniffer_Standards_IncorrectPatternException', true) ==
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.3
+ * @version   Release: 1.5.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_CodeSniffer_Sniff
@@ -96,7 +96,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      * Classes extending <i>AbstractPatternTest</i> should implement the
      * <i>getPatterns()</i> method to register the patterns they wish to test.
      *
-     * @return array(int)
+     * @return int[]
      * @see process()
      */
     public final function register()
@@ -146,7 +146,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      * @param array $pattern The parsed pattern to find the acquire the token
      *                       types from.
      *
-     * @return array(int => int)
+     * @return array<int, int>
      */
     private function _getPatternTokenTypes($pattern)
     {
@@ -270,7 +270,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      * @param int                  $stackPtr    The postion in the tokens stack where
      *                                          the listening token type was found.
      *
-     * @return array(errors)
+     * @return array
      */
     protected function processPattern(
         $patternInfo,
@@ -721,6 +721,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
         $found    = str_replace("\r\n", '\n', $found);
         $found    = str_replace("\n", '\n', $found);
         $found    = str_replace("\r", '\n', $found);
+        $found    = str_replace("\t", '\t', $found);
         $found    = str_replace('EOL', '\n', $found);
         $expected = str_replace('EOL', '\n', $patternCode);
 
@@ -734,7 +735,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
     /**
      * Returns the patterns that should be checked.
      *
-     * @return array(string)
+     * @return string[]
      */
     protected abstract function getPatterns();
 
@@ -746,7 +747,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      * an arbitary validation that cannot be performed using a pattern, with
      * other pattern tests.
      *
-     * @return array(int)
+     * @return int[]
      * @see processSupplementary()
      */
     protected function registerSupplementary()
