@@ -26,7 +26,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 1.5.3
+ * @version   Release: 1.5.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Sniff
@@ -69,15 +69,26 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
     protected $nonIndentingScopes = array();
 
     /**
-     * Stores the indent of the last PHP open tag we found.
+     * Stores the indent of the PHP open tags we found.
      *
      * This value is used to calculate the expected indent of top level structures
      * so we don't assume they are always at column 1. If PHP code is embedded inside
      * HTML (etc.) code, then the starting column for that code may not be column 1.
      *
-     * @var int
+     * @var int[]
      */
-    private $_openTagIndent = 0;
+    private $_openTagIndents = array();
+
+    /**
+     * Stores the indent of the PHP close tags we found.
+     *
+     * This value is used to calculate the expected indent of top level structures
+     * so we don't assume they are always at column 1. If PHP code is embedded inside
+     * HTML (etc.) code, then the starting column for that code may not be column 1.
+     *
+     * @var int[]
+     */
+    private $_closeTagIndents = array();
 
 
     /**
@@ -89,6 +100,7 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
     {
         $tokens   = PHP_CodeSniffer_Tokens::$scopeOpeners;
         $tokens[] = T_OPEN_TAG;
+        $tokens[] = T_CLOSE_TAG;
         return $tokens;
 
     }//end register()
@@ -109,9 +121,24 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
 
         // We only want to record the indent of open tags, not process them.
         if ($tokens[$stackPtr]['code'] == T_OPEN_TAG) {
-            if (empty($tokens[$stackPtr]['conditions']) === true) {
-                // Only record top-level PHP tags.
-                $this->_openTagIndent = ($tokens[$stackPtr]['column'] - 1);
+            $indent = ($tokens[$stackPtr]['column'] - 1);
+            if (empty($this->_closeTagIndents) === false
+                && $indent === $this->_closeTagIndents[0]
+            ) {
+                array_shift($this->_closeTagIndents);
+            } else {
+                array_unshift($this->_openTagIndents, $indent);
+            }
+
+            return;
+        }
+
+        if ($tokens[$stackPtr]['code'] == T_CLOSE_TAG) {
+            $indent = ($tokens[$stackPtr]['column'] - 1);
+            if ($indent === $this->_openTagIndents[0]) {
+                array_shift($this->_openTagIndents);
+            } else {
+                array_unshift($this->_closeTagIndents, $indent);
             }
 
             return;
@@ -387,7 +414,7 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
                 // carefully in another sniff.
                 return $tokens[$stackPtr]['column'];
             } else {
-                return ($this->_openTagIndent + 1);
+                return ($this->_openTagIndents[0] + 1);
             }
         }
 
@@ -429,6 +456,10 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
         // Increase by 1 to indiciate that the code should start at a specific column.
         // E.g., code indented 4 spaces should start at column 5.
         $indent++;
+
+        // Take the indent of the open tag into account.
+        $indent += $this->_openTagIndents[0];
+
         return $indent;
 
     }//end calculateExpectedIndent()
